@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataCSelWrapStruct::wrap_struct;
 
-our $DATE = '2016-08-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ Bencher::Scenario::DataCSelWrapStruct::wrap_struct - Benchmark wrap_struct()
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DataCSelWrapStruct::wrap_struct (from Perl distribution Bencher-Scenarios-DataCSelWrapStruct), released on 2016-08-26.
+This document describes version 0.003 of Bencher::Scenario::DataCSelWrapStruct::wrap_struct (from Perl distribution Bencher-Scenarios-DataCSelWrapStruct), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -52,11 +52,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Data::CSel::WrapStruct> 0.001
+L<Data::CSel::WrapStruct> 0.003
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -94,37 +98,36 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with C<< bencher -m DataCSelWrapStruct::wrap_struct --with-args-size --with-result-size >>:
 
  #table1#
  +-----------+-----------+-----------+------------+--------------------+------------------+---------+---------+
- | dataset   | rate (/s) | time (ms) | vs_slowest | arg_data_size (kB) | result_size (kB) |  errors | samples |
+ | dataset   | rate (/s) | time (μs) | vs_slowest | arg_data_size (kB) | result_size (kB) |  errors | samples |
  +-----------+-----------+-----------+------------+--------------------+------------------+---------+---------+
- | hash1000  |       610 |    1.6    |        1   |             91     |           310    | 9.1e-06 |      22 |
- | array1000 |       920 |    1.1    |        1.5 |             31     |           210    | 3.1e-06 |      20 |
- | hash100   |      6700 |    0.15   |       11   |              9.3   |            31    | 2.1e-07 |      20 |
- | array100  |      9000 |    0.11   |       15   |              3.2   |            21    | 2.1e-07 |      20 |
- | hash1     |    180000 |    0.0056 |      290   |              0.25  |             0.81 | 8.3e-09 |      20 |
- | array1    |    260000 |    0.0039 |      420   |              0.094 |             0.49 | 1.3e-08 |      20 |
- | scalar    |    840000 |    0.0012 |     1400   |              0.023 |             0.15 | 1.7e-09 |      20 |
+ | hash1000  |       726 | 1380      |       1    |           91       |         310      | 6.9e-07 |      20 |
+ | array1000 |      1280 |  784      |       1.76 |           31.3     |         211      | 4.8e-07 |      20 |
+ | hash100   |      8400 |  120      |      12    |            9.3     |          31      | 4.8e-07 |      20 |
+ | array100  |     12000 |   82      |      17    |            3.2     |          21      | 1.3e-07 |      20 |
+ | hash1     |    310000 |    3.2    |     430    |            0.25    |           0.81   | 6.7e-09 |      20 |
+ | array1    |    440000 |    2.3    |     600    |            0.094   |           0.49   | 3.3e-09 |      20 |
+ | scalar    |   1419000 |    0.7047 |    1955    |            0.02344 |           0.1484 | 4.6e-11 |      25 |
  +-----------+-----------+-----------+------------+--------------------+------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DataCSelWrapStruct::wrap_struct --module-startup >>):
 
  #table2#
- +------------------------+-----------+------------------------+------------+---------+---------+
- | participant            | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +------------------------+-----------+------------------------+------------+---------+---------+
- | Data::CSel::WrapStruct |       9.4 |                    3.6 |        1   | 4.7e-05 |      20 |
- | perl -e1 (baseline)    |       5.8 |                    0   |        1.6 | 5.5e-05 |      21 |
- +------------------------+-----------+------------------------+------------+---------+---------+
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant            | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Data::CSel::WrapStruct | 844                          | 4                  | 16             |      10   |                    3.8 |        1   | 2.6e-05 |      20 |
+ | perl -e1 (baseline)    | 1028                         | 4.5                | 16             |       6.2 |                    0   |        1.6 | 1.3e-05 |      20 |
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -148,7 +151,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
